@@ -1,7 +1,12 @@
+{-# LANGUAGE CPP                #-}
+{-# LANGUAGE DeriveDataTypeable #-}
+{-# LANGUAGE DeriveFoldable     #-}
+{-# LANGUAGE DeriveFunctor      #-}
+{-# LANGUAGE DeriveTraversable  #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Data.Monoid.Recommend
--- Copyright   :  (c) 2012 diagrams-core team (see LICENSE)
+-- Copyright   :  (c) 2012-2015 diagrams-core team (see LICENSE)
 -- License     :  BSD-style (see LICENSE)
 -- Maintainer  :  diagrams-discuss@googlegroups.com
 --
@@ -14,10 +19,17 @@
 -----------------------------------------------------------------------------
 
 module Data.Monoid.Recommend
-       ( Recommend(..), getRecommend
+       ( Recommend(..)
+       , getRecommend
        ) where
 
-import Data.Semigroup
+#if __GLASGOW_HASKELL__ < 710
+import           Data.Foldable
+import           Data.Traversable
+#endif
+
+import           Data.Data
+import           Data.Semigroup
 
 -- | A value of type @Recommend a@ consists of a value of type @a@
 --   wrapped up in one of two constructors.  The @Recommend@
@@ -28,7 +40,7 @@ import Data.Semigroup
 --   overriding any @Recommend@ed values.
 data Recommend a = Recommend a
                  | Commit a
-                   deriving Show
+  deriving (Show, Read, Functor, Eq, Ord, Typeable, Data, Foldable, Traversable)
 
 -- | Extract the value of type @a@ wrapped in @Recommend a@.
 getRecommend :: Recommend a -> a
